Crate tracking_allocator[][src]

tracking-allocator

This crate provides a global allocator implementation (compatible with [GlobalAlloc]) that allows users to trace allocations and deallocations directly. Allocation tokens can also be registered, which allows users to get an identifier that has associated metadata, which when used, can enhance the overall tracking of allocations.

While this allocator must be installed as the global allocator for the process, it ultimately defers to the std::alloc::System allocator to perform the actual allocations.

Structs

A token that uniquely identifies an allocation group.

Guard that updates the current thread to track allocations for the associated allocation group.

[Tracing] is a tracing_subscriber::Layer that handles entering and exiting an allocation group guard as the span it is attached to is entered and exited itself.

Handles registering tokens for tracking different allocation groups.

Tracking allocator implementation.

Returned if trying to set the global tracker fails.

Traits

Tracks allocations and deallocations.