Struct tracking_allocator::AllocationGroupToken[][src]

pub struct AllocationGroupToken(_);
A token that uniquely identifies an allocation group.

Implementations

Acquires an allocation group token.

Acquires an allocation group token, with tags.

While allocation groups are primarily represented by their AllocationGroupToken, users can use this method to attach specific tags – or key/value string pairs – to the group. These tags will be provided to the global tracker whenever an allocation event is associated with the allocation group.

Memory usage

In order to minimize any allocations while in the process of tracking normal allocations, we rely on utilizing only static references to data. If the tags given are not already 'static references, they will be leaked in order to make them 'static. Thus, callers should take care to avoid registering tokens on an ongoing basis when utilizing owned tags as this could create a persistent and ever-growing memory leak over the life of the process.

Marks the associated allocation group as the active allocation group on this thread.

If another allocation group is currently active, it is replaced, and restored either when this allocation guard is dropped, or when AllocationGuard::exit is called.

Attaches this allocation group to a tracing span.

When the span is entered or exited, the allocation group will also transition from idle to active, creating the beavhior of associating all allocations within the during of the entered span with the given allocation group.